"use strict";

// ADMOB, FIREBASE AND USER CONSENT INITIALIZATION ######################################################
let banner, interstitial, rewarded,
retryIntrstTimer = true, retryIntrst = 0,
retryRewardTimer = true, retryReward = 0;

document.addEventListener('deviceready', async () => {
    // Status bar and screen orientation **************************************************************
    StatusBar.hide(); 
    screen.orientation.lock('landscape');

	// Firebase ***************************************************************************************
	FirebasePlugin.isAnalyticsCollectionEnabled(function(enabled){
		console.log("Analytics data collection is "+(enabled ? "enabled" : "disabled"));
	}, function(error) {
		console.error("Error getting Analytics data collection setting: "+error);
	});
	FirebasePlugin.isCrashlyticsCollectionEnabled(function(enabled){
		console.log("Crashlytics data collection is "+(enabled ? "enabled" : "disabled"));
	}, function(error) {
		console.error("Error getting Crashlytics data collection setting: "+error);
	});
	FirebasePlugin.isPerformanceCollectionEnabled(function(enabled){
		console.log("Performance data collection is "+(enabled ? "enabled" : "disabled"));
	}, function(error) {
		console.error("Error getting Performance data collection setting: "+error);
	});

	// Init Yandex Ads *********************************************************************************
	if (lang.startsWith('ru')) {
		await YandexAds.init({ 
			rewardedBlockId: 'R-M-13186917-3',
			interstitialBlockId: 'R-M-13186917-2',
			bannerBlockId: 'R-M-13186917-1',
			options: { // This is for banner ads
				bannerAtTop: false, // Show banner on top of screen, otherwise on bottom
				// bannerSize: {width: 468, height: 100}, // You can skip bannerSize option and width will be as big as possible
			},
		}).then(() => {
			console.log('YandexAds.init');
			YandexAds.setUserConsent(true);
		}).catch((error) => {
			console.log('YandexAds.init error', error);
		});
		// Rewarded
		YandexAds.loadRewardedVideo({onSuccess: function() {},onFailure: function() {},});
		window.addEventListener(YandexAds.events.rewarded.loaded, onRewardedLoaded);
		window.addEventListener(YandexAds.events.rewarded.failedToLoad, onRewardedLoadFailed);
		window.addEventListener(YandexAds.events.rewarded.shown, onRewardedShown);
		window.addEventListener(YandexAds.events.rewarded.failedToShow, onRewardedShowFailed);
		window.addEventListener(YandexAds.events.rewarded.dismissed, onRewardedClosed);
		window.addEventListener(YandexAds.events.rewarded.rewarded, onRewardedComplete);
		window.addEventListener(YandexAds.events.rewarded.clicked,  (evt) => {});
		window.addEventListener(YandexAds.events.rewarded.impression,  (evt) => {});
		// Interstitial
		YandexAds.loadInterstitial();
		window.addEventListener(YandexAds.events.interstitial.loaded, onInterstitialLoaded);
		window.addEventListener(YandexAds.events.interstitial.failedToLoad, onInterstitialLoadFailed);
		window.addEventListener(YandexAds.events.interstitial.shown, onInterstitialShown);
		window.addEventListener(YandexAds.events.interstitial.failedToShow, onInterstitialShowFailed);
		window.addEventListener(YandexAds.events.interstitial.dismissed, onInterstitialClosed);
		window.addEventListener(YandexAds.events.interstitial.clicked,  (evt) => {});
		window.addEventListener(YandexAds.events.interstitial.impression,  (evt) => {});
		// Banner
		YandexAds.loadBanner();
		window.addEventListener(YandexAds.events.banner.loaded, (evt) => {YandexAds.showBanner();});
		window.addEventListener(YandexAds.events.banner.failedToLoad, (evt) => {});
		window.addEventListener(YandexAds.events.banner.impression, (evt) => {});
	} // Init AdMob and User Consent *******************************************************************
	else {
		if (await consent.canRequestAds()) {
			initAd(); console.log('consent.canRequestAds !!!');
		}
		else { console.log(' NOT consent.canRequestAds !!!');
			await consent.requestInfoUpdate();
			await consent.loadAndShowIfRequired();
			if (await consent.canRequestAds()) initAd();
		}
	}
}, false);

// AdMob **************************************************************************************
// admob.start();
// admob.start().then(() => admob.configure({testDeviceIds: ["33BE2250B43518CCDA7DE426D04EE231"],}),)
function initAd() {
	admob.start().then(() => console.log('admob.start !!!'));

	// Banner init **********************************************************************
	banner = new admob.BannerAd({
		adUnitId: 'ca-app-pub-4417067369966000/4403792053', 
		offset: 0,
	});

	// Banner Event Functions 
	banner.on('load', (evt) => {});
	banner.on('loadfail', (evt) => {});
	banner.on('impression', (evt) => {});
    banner.show();

	// Interstitial init ****************************************************************
	interstitial = new admob.InterstitialAd({
		adUnitId: 'ca-app-pub-4417067369966000/6974115072', 
	});
	interstitial.load();
	// Interstitial Event  
	interstitial.on('load', onInterstitialLoaded);
	interstitial.on('loadfail', onInterstitialLoadFailed);
	interstitial.on('show', onInterstitialShown);
	interstitial.on('showfail', onInterstitialShowFailed);
	interstitial.on('dismiss', onInterstitialClosed);

	// Rewarded init ********************************************************************
	rewarded = new admob.RewardedAd({
		adUnitId: 'ca-app-pub-4417067369966000/9506099013', 
	});
	rewarded.load();
	// Rewarded Event  
	rewarded.on('load', onRewardedLoaded);
	rewarded.on('loadfail', onRewardedLoadFailed);
	rewarded.on('show', onRewardedShown);
	rewarded.on('showfail', onRewardedShowFailed);
	rewarded.on('dismiss', onRewardedClosed);
	rewarded.on('reward', onRewardedComplete);
}

// Banner Event Functions ********************************************************************************
function onBannerLoaded() {}
function onBannerLoadFailed() {}
function onBannerShown() {}
function onBannerShowFailed() {}
function onBannerClicked() {}
function onBannerClosed() {}

// Interstitial Events Functions ************************************************************************
function onInterstitialLoaded() {
    // intrstFailFlag = false;
    if (retryIntrstTimer) {
		clearTimeout(retryIntrstTimer); retryIntrstTimer = false; retryIntrst = 0;
	}
}
function onInterstitialLoadFailed() {
    // intrstFailFlag = true;
    retryIntrst++;
	let delayIntrst = Math.pow(2, Math.min(6, retryIntrst));
	retryIntrstTimer = setTimeout(() => {
		if (lang.startsWith('ru')) YandexAds.loadInterstitial();
		else interstitial.load(); // loadInterVideo();
	}, delayIntrst * 1000);
}
function onInterstitialShowFailed() {
    // intrstFailFlag = true; 
    if (lang.startsWith('ru')) YandexAds.loadInterstitial();
	else interstitial.load(); 
    contGame();
}
function onInterstitialShown() {
    if (volumeData.musicFlag == 'on') locMusik.pause();
    transIntrstNum = 0;
}
function onInterstitialClicked() {}
function onInterstitialClosed() {
    if (lang.startsWith('ru')) YandexAds.loadInterstitial();
	else interstitial.load(); 
    contGame();
    if (volumeData.musicFlag == 'on' && locMusik.paused) locMusik.play();
}
function onInterstitialComplete() {}

// Reward Events Functions *******************************************************************************
function onRewardedLoaded() {
    // rewardFailFlag = false;
    if (retryRewardTimer) {
		clearTimeout(retryRewardTimer); retryRewardTimer = false; retryReward = 0;
	} 
    numAds.style.display = 'block'; waitAds.style.display = 'none';
    numAdsShop.style.display = 'block'; waitAdsShop.style.display = 'none';
    watchAdsMes.style.display = 'block'; waitAdsMes.style.display = 'none';
}
function onRewardedLoadFailed() {
    // rewardFailFlag = true; 
    retryReward++;
	let delayIntrst = Math.pow(2, Math.min(6, retryReward));
	retryRewardTimer = setTimeout(() => {
		if (lang.startsWith('ru')) YandexAds.loadRewardedVideo();
		else rewarded.load();
	}, delayIntrst * 1000);
    numAds.style.display = 'none'; waitAds.style.display = 'block';
    numAdsShop.style.display = 'none'; waitAdsShop.style.display = 'block';
    watchAdsMes.style.display = 'none'; waitAdsMes.style.display = 'block';
}
function onRewardedShowFailed() { console.log('onRewardedShowFailed');
    // rewardFailFlag = true;
    if (lang.startsWith('ru')) YandexAds.loadRewardedVideo();
	else rewarded.load();
    numAds.style.display = 'none'; waitAds.style.display = 'block';
    numAdsShop.style.display = 'none'; waitAdsShop.style.display = 'block';
    watchAdsMes.style.display = 'none'; waitAdsMes.style.display = 'block';
    // Исчезновения окна награды за видео 
    if (mesMainMA.style.display == 'block') {
        rewardPics.forEach(function(item) {item.style.display = 'none';});
        mesReward.style.display = 'none'; mesMainMA.style.display = 'none';
        iRewCell = null; contGame();
    }
}
function onRewardedShown() {
    if (volumeData.musicFlag == 'on') locMusik.pause();
    transIntrstNum = 0;
}
function onRewardedClicked() {}
function onRewardedClosed() { console.log('onRewardedClosed');
    if (lang.startsWith('ru')) YandexAds.loadRewardedVideo();
	else rewarded.load();
    // Исчезновения окна награды за видео с птицами
    if (mesMainMA.style.display == 'block') {
        rewardPics.forEach(function(item) {item.style.display = 'none';});
        mesReward.style.display = 'none'; mesMainMA.style.display = 'none';
        iRewCell = null; contGame();
    }
    if (volumeData.musicFlag == 'on' && locMusik.paused) locMusik.play();
}
function onRewardedComplete() { console.log('onRewardedComplete');
    // Rewarded ad was displayed and user should receive the reward
    // Награда от птиц
    if (mesMainMA.style.display == 'block') {
        if (rewardNum > 0) {
            if (potionsMenu[rewardNum - 1].style.display !== 'block') {
                potionsMenu[rewardNum - 1].style.display = 'block'; itemsInMenu.potionInMenu[rewardNum - 1] = true;
                menuCells[iRewCell].classList.add('taken-cell'); menuCells[iRewCell].classList.add(potionClassName[rewardNum - 1]);
                displacementLS(iRewCell, potionsMenu[rewardNum - 1]);
            } itemsInMenu.potionNum[rewardNum - 1] += 1; potionsQuant[rewardNum - 1].innerHTML = itemsInMenu.potionNum[rewardNum - 1];
        } else if (rewardNum == 0) {
            charData.moneyNum += moneyRewNum; 
            coinsMenu.innerHTML = charData.moneyNum; coinsMainMA.innerHTML = charData.moneyNum;
        } // Запись в LS
        window.localStorage.setItem("dataCharKey3", JSON.stringify(charData)); 
        window.localStorage.setItem("itemsInMenuKey3", JSON.stringify(itemsInMenu)); 
    } // Уменьшение колич просмотров рекламы в кнопке в sb window 
    else if (trader.style.display == 'block') {
        watchAdsStimNum[numPot] -= 1;
        if (watchAdsStimNum[numPot] <= 0) {
            watchAdsStimNum[numPot] = watchAdsStimConst[numPot];
            // Появление стимулятора и присваивание классов занятой ячейки
            for (let i = 0; i < 16; i++) { 
                if (!menuCells[i].classList.contains('taken-cell') || potionsMenu[numPot].style.display == 'block') {
                    // Появление предмета в ячейке меню и присваивание флага появившего предмета
                    if (potionsMenu[numPot].style.display !== 'block') {
                        menuCells[i].classList.add('taken-cell'); menuCells[i].classList.add(potionClassName[numPot]);
                        potionsMenu[numPot].style.display = 'block'; displacementLS(i, potionsMenu[numPot]); itemsInMenu.potionInMenu[numPot] = true; 
                    } // Увеличение количества зелий в меню
                    itemsInMenu.potionNum[numPot] += 1; potionsQuant[numPot].innerHTML = itemsInMenu.potionNum[numPot];
                    break;
                } 
            } window.localStorage.setItem("itemsInMenuKey3", JSON.stringify(itemsInMenu));
        } // Show number ads
        if (langNum == 1) {
            if (watchAdsStimNum[numPot] == 1 || watchAdsStimNum[numPot] == 5) numAds.innerHTML = watchAdsStimNum[numPot] + ' раз';
            else numAds.innerHTML = watchAdsStimNum[numPot] + ' раза';
        } else if (langNum == 2) numAds.innerHTML = watchAdsStimNum[numPot] + ' vezes';
        else numAds.innerHTML = watchAdsStimNum[numPot] + ' times';
        window.localStorage.setItem("watchAdsStimNumKey3", JSON.stringify(watchAdsStimNum));
    } // Уменьшение колич просмотров рекламы в кнопке в info shop window 
    else if (shopMenu.style.display == 'block') {
        watchAdsPurchNum[infoNum] -= 1;
        if (watchAdsPurchNum[infoNum] <= 0) {
            watchAdsPurchNum[infoNum] = watchAdsPurchConst[infoNum];
            // Receiving money and sp 
            if (infoNum < 3) {
                if (infoNum == 0) charData.moneyNum += moneyShopItemNum; 
                else if (infoNum == 1) charData.moneyNum += moneyShopItemNum * 6; 
                else if (infoNum == 2) charData.moneyNum += moneyShopItemNum * 14;
                coinsMenu.innerHTML = charData.moneyNum; 
                coinsMainMA.innerHTML = charData.moneyNum;
                qantCoinShop.innerHTML = charData.moneyNum;
            } else {
                if (infoNum == 3) charData.stPointsNum += spShopItemNum; 
                else if (infoNum == 4) charData.stPointsNum += spShopItemNum * 5; 
                else if (infoNum == 5) charData.stPointsNum += spShopItemNum * 10;
                spInfo.innerHTML = charData.stPointsNum;
                qantSpShop.innerHTML = charData.stPointsNum;
            } window.localStorage.setItem("dataCharKey3", JSON.stringify(charData));
        } // Show number ads
        if (langNum == 1) {
            if (watchAdsPurchNum[infoNum] == 1 || watchAdsPurchNum[infoNum] == 5) numAdsShop.innerHTML = watchAdsPurchNum[infoNum] + ' раз';
            else numAdsShop.innerHTML = watchAdsPurchNum[infoNum] + ' раза';
        } else if (langNum == 2) numAdsShop.innerHTML = watchAdsPurchNum[infoNum] + ' vezes';
        else numAdsShop.innerHTML = watchAdsPurchNum[infoNum] + ' times';
        window.localStorage.setItem("watchAdsPurchNumKey3", JSON.stringify(watchAdsPurchNum));
    }
}



// STORE INITIALIZATION ##################################################################################
let moneyProduct1, moneyProduct2, spProduct1, spProduct2,
buyPurchNum = null;

document.addEventListener("deviceready", storeInitialization, false);

function storeInitialization() {  
	CdvPurchase.store.verbosity = store.DEBUG;
    CdvPurchase.store.register([
        {id: 'barsukstudio.minerclicker.money_1', type: CdvPurchase.CONSUMABLE, platform: CdvPurchase.Platform.GOOGLE_PLAY,},
        { id: 'barsukstudio.minerclicker.money_2', type: CdvPurchase.CONSUMABLE, platform: CdvPurchase.Platform.GOOGLE_PLAY,},
        { id: 'barsukstudio.minerclicker.sp_1', type: CdvPurchase.CONSUMABLE, platform: CdvPurchase.Platform.GOOGLE_PLAY,},
        { id: 'barsukstudio.minerclicker.sp_2', type: CdvPurchase.CONSUMABLE, platform: CdvPurchase.Platform.GOOGLE_PLAY,}
    ]);

    CdvPurchase.store.when()
        .productUpdated(refreshUI) 
	    .approved((transaction) => {
            console.log(transaction);
            if (buyPurchNum == null) transaction.finish();
            else if (transaction.state === 'approved') transaction.verify();
            CdvPurchase.store.getAdapter(CdvPurchase.Platform.GOOGLE_PLAY).bridge.consumePurchase(
                function (x) { console.log(x); }, 
                function (e) { console.log("err",e); }, 
                transaction.purchaseId);
        }).verified((transaction) => {
            if (buyPurchNum == 0) {
				charData.moneyNum += 8000000; 
                coinsMenu.innerHTML = charData.moneyNum; coinsMainMA.innerHTML = charData.moneyNum; qantCoinShop.innerHTML = charData.moneyNum;
			} else if (buyPurchNum == 1) {
				charData.moneyNum += 40000000; 
                coinsMenu.innerHTML = charData.moneyNum; coinsMainMA.innerHTML = charData.moneyNum; qantCoinShop.innerHTML = charData.moneyNum;
			} else if (buyPurchNum == 2) {
				charData.stPointsNum += 250; 
                spInfo.innerHTML = charData.stPointsNum; qantSpShop.innerHTML = charData.stPointsNum;
			} else if (buyPurchNum == 3) {
				charData.stPointsNum += 1250; 
                spInfo.innerHTML = charData.stPointsNum; qantSpShop.innerHTML = charData.stPointsNum;
			} window.localStorage.setItem("dataCharKey3", JSON.stringify(charData));
			transaction.finish();
        });

    CdvPurchase.store.initialize([CdvPurchase.Platform.GOOGLE_PLAY]).then((err) => {
        console.log('store.initialize');
        moneyProduct1 = CdvPurchase.store.get('barsukstudio.minerclicker.money_1', CdvPurchase.Platform.GOOGLE_PLAY);
        moneyProduct2 = CdvPurchase.store.get('barsukstudio.minerclicker.money_2', CdvPurchase.Platform.GOOGLE_PLAY);
        spProduct1 = CdvPurchase.store.get('barsukstudio.minerclicker.sp_1', CdvPurchase.Platform.GOOGLE_PLAY);
        spProduct2 = CdvPurchase.store.get('barsukstudio.minerclicker.sp_2', CdvPurchase.Platform.GOOGLE_PLAY);
        purchPriceNum[0] = moneyProduct1.offers[0].pricingPhases[0].price; //moneyProduct1.pricing.price;
        purchPriceNum[1] = moneyProduct2.offers[0].pricingPhases[0].price; //pricing.price; //pricingPhases[0].price
        purchPriceNum[2] = spProduct1.offers[0].pricingPhases[0].price; //spProduct1.pricing.price;
        purchPriceNum[3] = spProduct2.offers[0].pricingPhases[0].price; //spProduct2.pricing.price;
    });
    // CdvPurchase.store.update([CdvPurchase.Platform.GOOGLE_PLAY]).then((evt) => {console.log('evt');});
    // CdvPurchase.store.restorePurchases([CdvPurchase.Platform.GOOGLE_PLAY]);
}
    
function refreshUI(product) {
    console.log('refreshUI');
}
// store.order(moneyProduct1.getOffer());
// const offer = product.getOffer("offer-id"); CdvPurchase.store.order(offer);
function purchaseMoney1() {buyPurchNum = 0; CdvPurchase.store.order(moneyProduct1.getOffer());} //moneyProduct1.getOffer().order();
function purchaseMoney2() {buyPurchNum = 1; CdvPurchase.store.order(moneyProduct2.getOffer());} // moneyProduct2.getOffer().order();
function purchaseSP1() {buyPurchNum = 2; CdvPurchase.store.order(spProduct1.getOffer());} //spProduct1.getOffer().order();
function purchaseSP2() {buyPurchNum = 3; CdvPurchase.store.order(spProduct2.getOffer());} //spProduct2.getOffer().order();






// Кнопка назад на устройстве ******************************************************************
document.addEventListener("backbutton", onBackKeyDown, false);
function onBackKeyDown() {
    if (locNum > 1) {
        if (menuFlag) {
            // Закрытие опций
            if (optMenu.style.display == 'block') closeOptMenu();
            // Закрытие меню 
            else if (charMenu.style.display == 'block') exitMenuFunc();
            // Закрытие магазина
            else if (shopMenu.style.display == 'block') {
                if (infoWind.style.display == 'block') {
                    infoItem[infoNum].style.display = 'none'; infoWind.style.display = 'none';
                    if (btnShopBuy.style.display == 'block') btnShopBuy.style.display = 'none';
        	        if (btnShopWatch.style.display == 'block') btnShopWatch.style.display = 'none';
                } shopMenu.style.display = 'none'; 
                contGame(); menuFlag = false;
            } 
        } else { 
            stopGame(); // Stop game
            initNewLocation(1); // Show new location
            // Hide bird
            if (moveBirdIntrvl) {
                cancelAnimationFrame(moveBirdIntrvl); moveBirdIntrvl = null;
                birdX = 0; birdY = 0; bird[birdNum].style.transform = 'translate(' + birdX + 'px, ' + birdY + 'px)'; 
            } // Счетчик показа окна оценки игры
            if (!rateFlag) transRateNum += 1; 
            // Счетчик показа межстранички
            transIntrstNum += 1;
            // MesRate show
            if (transRateNum >= 10 && rateFlag == 0) {
                transRateNum = 0; mesMainMA.style.display = 'block'; mesRate.style.display = 'block';
            } // Intrst ads 
            else if (transIntrstNum >= 4 && !intrstFailFlag) showInterVideo();
            // Trans on map window
            else {
                // if (intrstFailFlag) interstitial.load();
                contGame(); // Continue game
            } // Set in LS 
            window.localStorage.setItem("transRateKey3", transRateNum); 
        }
    } else if (locNum == 1) {
        if (mesMainMA.style.display == 'block') {
            btnsTutorial.style.display = 'none'; mesTutorial[numTutorial].style.display = 'none'; 
            windCloseTutorial.style.display = 'block';
        } else if (optMenu.style.display == 'block') closeOptMenu();
        else if (charMenu.style.display == 'block') exitMenuFunc();
        else if (shopMenu.style.display == 'block') {
            if (infoWind.style.display == 'block') {
                infoItem[infoNum].style.display = 'none'; infoWind.style.display = 'none';
                if (btnShopBuy.style.display == 'block') btnShopBuy.style.display = 'none';
                if (btnShopWatch.style.display == 'block') btnShopWatch.style.display = 'none';
            } shopMenu.style.display = 'none'; 
            contGame(); menuFlag = false;
            // Show tutorial
            if (!finishTutorialFlag) {
                mesTutorialMA.style.display = 'block'; mesMainMA.style.display = 'block';  mesTutorial[numTutorial].style.display = 'block';
            }
        } else if (mesMainMA.style.display !== 'block') {
            stopGame(); // Stop game
            // Show start window
            locat[locNum].style.display = 'none'; locNum = 0; locat[locNum].style.display = 'block';
        }
    } else if (locNum == 0) navigator.app.exitApp();
}



// Перевод приложения в фоновый режим ********************************************************************
document.addEventListener("pause", onPause, false);
function onPause() {
    if (volumeData.musicFlag == 'on') locMusik.pause();
    if (!menuFlag && mesMainMA.style.display !== 'block') stopGame();
}
// Возврат приложение из фонового режима
document.addEventListener("resume", onResume, false);
function onResume() {
    if (!menuFlag && mesMainMA.style.display !== 'block') contGame();
    if (volumeData.musicFlag == 'on' && locMusik.paused) locMusik.play();
}


// Hide load wind and show main window ####################################################################
window.onload = function() {
    showWordsFunc();    
}





